"""Top-level package for safe-reboot."""

__author__ = """Sebastian Wallat"""
__email__ = 'devwallat@gmail.com'
__version__ = '0.2.0'
